@@ -11,7 +11,7 @@ class GitlabSchema < GraphQL::Schema
   use Gitlab::Graphql::Authorize
   use Gitlab::Graphql::Present
   use Gitlab::Graphql::Connections
-  use Gitlab::Graphql::Tracing
+  use Gitlab::Graphql::GenericTracing
 
   query_analyzer Gitlab::Graphql::QueryAnalyzers::LogQueryComplexity.analyzer
 
