@@ -17,13 +17,13 @@ class RemoteMirror < ApplicationRecord
 
   belongs_to :project, inverse_of: :remote_mirrors
 
-  validates :url, presence: true, public_url: { protocols: %w(ssh git http https), allow_blank: true, enforce_user: true }
+  validates :url, presence: true, public_url: { schemes: %w(ssh git http https), allow_blank: true, enforce_user: true }
 
   before_save :set_new_remote_name, if: :mirror_url_changed?
 
   after_save :set_override_remote_mirror_available, unless: -> { Gitlab::CurrentSettings.current_application_settings.mirror_available }
-  after_save :refresh_remote, if: :mirror_url_changed?
-  after_update :reset_fields, if: :mirror_url_changed?
+  after_save :refresh_remote, if: :saved_change_to_mirror_url?
+  after_update :reset_fields, if: :saved_change_to_mirror_url?
 
   after_commit :remove_remote, on: :destroy
 
@@ -133,6 +133,10 @@ class RemoteMirror < ApplicationRecord
   end
   alias_method :enabled?, :enabled
 
+  def disabled?
+    !enabled?
+  end
+
   def updated_since?(timestamp)
     last_update_started_at && last_update_started_at > timestamp && !update_failed?
   end
@@ -248,7 +252,7 @@ class RemoteMirror < ApplicationRecord
 
     # Before adding a new remote we have to delete the data from
     # the previous remote name
-    prev_remote_name = remote_name_was || fallback_remote_name
+    prev_remote_name = remote_name_before_last_save || fallback_remote_name
     run_after_commit do
       project.repository.async_remove_remote(prev_remote_name)
     end
@@ -265,4 +269,8 @@ class RemoteMirror < ApplicationRecord
   def mirror_url_changed?
     url_changed? || credentials_changed?
   end
+
+  def saved_change_to_mirror_url?
+    saved_change_to_url? || saved_change_to_credentials?
+  end
 end
