@@ -51,6 +51,11 @@ module API
           optional :avatar, type: File, desc: 'Avatar image for user'
           optional :private_profile, type: Boolean, desc: 'Flag indicating the user has a private profile'
           all_or_none_of :extern_uid, :provider
+
+          if Gitlab.ee?
+            optional :shared_runners_minutes_limit, type: Integer, desc: 'Pipeline minutes quota for this user'
+            optional :extra_shared_runners_minutes_limit, type: Integer, desc: '(admin-only) Extra pipeline minutes quota for this user'
+          end
         end
 
         params :sort_params do
@@ -80,6 +85,10 @@ module API
         use :sort_params
         use :pagination
         use :with_custom_attributes
+
+        if Gitlab.ee?
+          optional :skip_ldap, type: Boolean, default: false, desc: 'Skip LDAP users'
+        end
       end
       # rubocop: disable CodeReuse/ActiveRecord
       get do
@@ -124,7 +133,7 @@ module API
         user = User.find_by(id: params[:id])
         not_found!('User') unless user && can?(current_user, :read_user, user)
 
-        opts = { with: current_user&.admin? ? Entities::UserWithAdmin : Entities::User, current_user: current_user }
+        opts = { with: current_user&.admin? ? Entities::UserDetailsWithAdmin : Entities::User, current_user: current_user }
         user, opts = with_custom_attributes(user, opts)
 
         present user, opts
